@@ -63,6 +63,8 @@ Status_4_Evar.prototype =
 	addonbarCloseButton:		false,
 	addonbarWindowGripper:		true,
 
+	advancedUrlbarForceBinding:	false,
+
 	downloadColorActive:		null,
 	downloadColorPaused:		null,
 	downloadForce:			false,
@@ -141,7 +143,23 @@ Status_4_Evar.prototype =
 			},
 			updateWindow: function(win)
 			{
-				win.caligon.status4evar.updateWindowGripper(true);
+				win.caligon.status4evar.windowGripper.update(true);
+			}
+		},
+
+		"advanced.urlbar.forceBinding":
+		{
+			update: function()
+			{
+				this.advancedUrlbarForceBinding = this.prefs.getBoolPref("advanced.urlbar.forceBinding");
+			},
+			updateWindow: function(win)
+			{
+				let urlbar = win.caligon.status4evar.getters.urlbar;
+				if(urlbar)
+				{
+					this.setBoolElementAttribute(urlbar, "s4eforce", this.advancedUrlbarForceBinding);
+				}
 			}
 		},
 
